import _defineProperty from "@babel/runtime/helpers/defineProperty";
import { TYPES, fetch, cancel, fetchSuccess, fetchError, fetchItem, cancelItem, fetchSkill, cancelSkill, fetchSpecialization, cancelSpecialization, fetchTrait, cancelTrait } from './actions';
import { KEYS, PATHS } from './constants';
var FETCH = TYPES.FETCH,
    CANCEL = TYPES.CANCEL,
    FETCH_SUCCESS = TYPES.FETCH_SUCCESS,
    FETCH_ERROR = TYPES.FETCH_ERROR;
var dataKey = KEYS.DATA,
    errorKey = KEYS.ERROR;
var itemsPath = PATHS.ITEMS,
    skillsPath = PATHS.SKILLS,
    specializationsPath = PATHS.SPECIALIZATIONS,
    traitsPath = PATHS.TRAITS;
var id = 12345;
describe('actions', function () {
  describe('fetch', function () {
    it('should correctly transform action payload', function () {
      expect(fetch(id)).toEqual({
        payload: id,
        type: FETCH
      });
    });
  });
  describe('cancel', function () {
    it('should correctly transform action payload', function () {
      expect(cancel(id)).toEqual({
        payload: id,
        type: CANCEL
      });
    });
  });
  describe('fetchSuccess', function () {
    it('should correctly transform action payload', function () {
      var _fetchSuccess;

      var data = 'data';
      var path = 'test';
      expect(fetchSuccess((_fetchSuccess = {}, _defineProperty(_fetchSuccess, dataKey, data), _defineProperty(_fetchSuccess, "id", id), _defineProperty(_fetchSuccess, "path", path), _fetchSuccess))).toEqual({
        payload: data,
        type: FETCH_SUCCESS,
        meta: {
          id: id,
          path: path
        }
      });
    });
  });
  describe('fetchError', function () {
    it('should correctly transform action payload', function () {
      var _fetchError;

      var error = {
        message: 'error'
      };
      var path = 'path';
      expect(fetchError((_fetchError = {}, _defineProperty(_fetchError, errorKey, error), _defineProperty(_fetchError, "id", id), _defineProperty(_fetchError, "path", path), _fetchError))).toEqual({
        payload: error,
        type: FETCH_ERROR,
        meta: {
          id: id,
          path: path
        }
      });
    });
  });
  describe('fetchItem', function () {
    it('should correctly transform action payload', function () {
      expect(fetchItem(id)).toEqual({
        payload: {
          id: id,
          path: itemsPath
        },
        type: FETCH
      });
    });
  });
  describe('cancelItem', function () {
    it('should correctly transform action payload', function () {
      expect(cancelItem(id)).toEqual({
        payload: {
          id: id,
          path: itemsPath
        },
        type: CANCEL
      });
    });
  });
  describe('fetchSkill', function () {
    it('should correctly transform action payload', function () {
      expect(fetchSkill(id)).toEqual({
        payload: {
          id: id,
          path: skillsPath
        },
        type: FETCH
      });
    });
  });
  describe('cancelSkill', function () {
    it('should correctly transform action payload', function () {
      expect(cancelSkill(id)).toEqual({
        payload: {
          id: id,
          path: skillsPath
        },
        type: CANCEL
      });
    });
  });
  describe('fetchSpecialization', function () {
    it('should correctly transform action payload', function () {
      expect(fetchSpecialization(id)).toEqual({
        payload: {
          id: id,
          path: specializationsPath
        },
        type: FETCH
      });
    });
  });
  describe('cancelSpecialization', function () {
    it('should correctly transform action payload', function () {
      expect(cancelSpecialization(id)).toEqual({
        payload: {
          id: id,
          path: specializationsPath
        },
        type: CANCEL
      });
    });
  });
  describe('fetchTrait', function () {
    it('should correctly transform action payload', function () {
      expect(fetchTrait(id)).toEqual({
        payload: {
          id: id,
          path: traitsPath
        },
        type: FETCH
      });
    });
  });
  describe('cancelTrait', function () {
    it('should correctly transform action payload', function () {
      expect(cancelTrait(id)).toEqual({
        payload: {
          id: id,
          path: traitsPath
        },
        type: CANCEL
      });
    });
  });
});
//# sourceMappingURL=actions.spec.js.map