import _regeneratorRuntime from "@babel/runtime/regenerator";
import _defineProperty from "@babel/runtime/helpers/defineProperty";

var _marked = _regeneratorRuntime.mark(sendRequest),
    _marked2 = _regeneratorRuntime.mark(cancelRequest),
    _marked3 = _regeneratorRuntime.mark(saga);

import { take, fork, call, put, cancel as cancelEffect, cancelled, race, join, delay } from 'redux-saga/effects';
import axios from 'axios';
import { fetch, cancel, fetchSuccess, fetchError } from './actions';
import { BASE_URL as baseURL, KEYS } from './constants';
var create = axios.create,
    CancelToken = axios.CancelToken;
var axiosInstance = create({
  baseURL: baseURL
});
var dataKey = KEYS.DATA,
    errorKey = KEYS.ERROR;
var cancelType = cancel.toString();
var maxRetries = 10;
var retriableStatusCodes = [429, 500];

var getJitter = function getJitter() {
  return Math.floor(Math.random() * 1001) - 500;
};

function sendRequest(_ref) {
  var _ref$payload, id, path, abortSource, i, _yield$call, data, status, message, _error$response, _status, _error$response$data, text;

  return _regeneratorRuntime.wrap(function sendRequest$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
          _ref$payload = _ref.payload, id = _ref$payload.id, path = _ref$payload.path;
          _context.prev = 1;
          i = 0;

        case 3:
          if (!(i < maxRetries)) {
            _context.next = 27;
            break;
          }

          _context.prev = 4;
          abortSource = CancelToken.source();
          _context.next = 8;
          return call([axiosInstance, 'get'], "/".concat(path, "/").concat(id, "?lang=en"), {
            cancelToken: abortSource.token
          });

        case 8:
          _yield$call = _context.sent;
          data = _yield$call.data;
          _context.next = 12;
          return put(fetchSuccess(_defineProperty({
            id: id,
            path: path
          }, dataKey, data)));

        case 12:
          return _context.abrupt("return");

        case 15:
          _context.prev = 15;
          _context.t0 = _context["catch"](4);
          status = _context.t0.response.status;

          if (!(i < maxRetries - 1 && retriableStatusCodes.includes(status))) {
            _context.next = 23;
            break;
          }

          _context.next = 21;
          return delay(Math.pow(2, i) * 1000 + getJitter());

        case 21:
          _context.next = 24;
          break;

        case 23:
          throw _context.t0;

        case 24:
          i += 1;
          _context.next = 3;
          break;

        case 27:
          _context.next = 38;
          break;

        case 29:
          _context.prev = 29;
          _context.t1 = _context["catch"](1);
          message = _context.t1.message, _error$response = _context.t1.response;
          _error$response = _error$response === void 0 ? {} : _error$response;
          _status = _error$response.status, _error$response$data = _error$response.data;
          _error$response$data = _error$response$data === void 0 ? {} : _error$response$data;
          text = _error$response$data.text;
          _context.next = 38;
          return put(fetchError(_defineProperty({
            id: id,
            path: path
          }, errorKey, {
            message: text || message,
            status: _status
          })));

        case 38:
          _context.prev = 38;
          _context.next = 41;
          return cancelled() && !abortSource;

        case 41:
          if (!_context.sent) {
            _context.next = 44;
            break;
          }

          _context.next = 44;
          return call([abortSource, 'cancel']);

        case 44:
          return _context.finish(38);

        case 45:
        case "end":
          return _context.stop();
      }
    }
  }, _marked, null, [[1, 29, 38, 45], [4, 15]]);
}

function cancelRequest(_ref2, fetchTask) {
  var fetchId, fetchPath, _yield$race, abortingAction;

  return _regeneratorRuntime.wrap(function cancelRequest$(_context2) {
    while (1) {
      switch (_context2.prev = _context2.next) {
        case 0:
          fetchId = _ref2.id, fetchPath = _ref2.path;
          _context2.next = 3;
          return race({
            taskFinished: join(fetchTask),
            abortingAction: take(function (_ref3) {
              var type = _ref3.type,
                  _ref3$payload = _ref3.payload,
                  id = _ref3$payload.id,
                  path = _ref3$payload.path;
              return type === cancelType && fetchId === id && fetchPath === path;
            })
          });

        case 3:
          _yield$race = _context2.sent;
          abortingAction = _yield$race.abortingAction;

          if (!abortingAction) {
            _context2.next = 8;
            break;
          }

          _context2.next = 8;
          return cancelEffect(fetchTask);

        case 8:
        case "end":
          return _context2.stop();
      }
    }
  }, _marked2);
}

export default function saga() {
  var action, fetchTask;
  return _regeneratorRuntime.wrap(function saga$(_context3) {
    while (1) {
      switch (_context3.prev = _context3.next) {
        case 0:
          if (!true) {
            _context3.next = 11;
            break;
          }

          _context3.next = 3;
          return take(fetch);

        case 3:
          action = _context3.sent;
          _context3.next = 6;
          return fork(sendRequest, action);

        case 6:
          fetchTask = _context3.sent;
          _context3.next = 9;
          return fork(cancelRequest, action.payload, fetchTask);

        case 9:
          _context3.next = 0;
          break;

        case 11:
        case "end":
          return _context3.stop();
      }
    }
  }, _marked3);
}
//# sourceMappingURL=sagas.js.map