"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _actions = require("./actions");

var _constants = require("./constants");

var FETCH = _actions.TYPES.FETCH,
    CANCEL = _actions.TYPES.CANCEL,
    FETCH_SUCCESS = _actions.TYPES.FETCH_SUCCESS,
    FETCH_ERROR = _actions.TYPES.FETCH_ERROR;
var dataKey = _constants.KEYS.DATA,
    errorKey = _constants.KEYS.ERROR;
var itemsPath = _constants.PATHS.ITEMS,
    skillsPath = _constants.PATHS.SKILLS,
    specializationsPath = _constants.PATHS.SPECIALIZATIONS,
    traitsPath = _constants.PATHS.TRAITS;
var id = 12345;
describe('actions', function () {
  describe('fetch', function () {
    it('should correctly transform action payload', function () {
      expect((0, _actions.fetch)(id)).toEqual({
        payload: id,
        type: FETCH
      });
    });
  });
  describe('cancel', function () {
    it('should correctly transform action payload', function () {
      expect((0, _actions.cancel)(id)).toEqual({
        payload: id,
        type: CANCEL
      });
    });
  });
  describe('fetchSuccess', function () {
    it('should correctly transform action payload', function () {
      var _fetchSuccess;

      var data = 'data';
      var path = 'test';
      expect((0, _actions.fetchSuccess)((_fetchSuccess = {}, (0, _defineProperty2["default"])(_fetchSuccess, dataKey, data), (0, _defineProperty2["default"])(_fetchSuccess, "id", id), (0, _defineProperty2["default"])(_fetchSuccess, "path", path), _fetchSuccess))).toEqual({
        payload: data,
        type: FETCH_SUCCESS,
        meta: {
          id: id,
          path: path
        }
      });
    });
  });
  describe('fetchError', function () {
    it('should correctly transform action payload', function () {
      var _fetchError;

      var error = {
        message: 'error'
      };
      var path = 'path';
      expect((0, _actions.fetchError)((_fetchError = {}, (0, _defineProperty2["default"])(_fetchError, errorKey, error), (0, _defineProperty2["default"])(_fetchError, "id", id), (0, _defineProperty2["default"])(_fetchError, "path", path), _fetchError))).toEqual({
        payload: error,
        type: FETCH_ERROR,
        meta: {
          id: id,
          path: path
        }
      });
    });
  });
  describe('fetchItem', function () {
    it('should correctly transform action payload', function () {
      expect((0, _actions.fetchItem)(id)).toEqual({
        payload: {
          id: id,
          path: itemsPath
        },
        type: FETCH
      });
    });
  });
  describe('cancelItem', function () {
    it('should correctly transform action payload', function () {
      expect((0, _actions.cancelItem)(id)).toEqual({
        payload: {
          id: id,
          path: itemsPath
        },
        type: CANCEL
      });
    });
  });
  describe('fetchSkill', function () {
    it('should correctly transform action payload', function () {
      expect((0, _actions.fetchSkill)(id)).toEqual({
        payload: {
          id: id,
          path: skillsPath
        },
        type: FETCH
      });
    });
  });
  describe('cancelSkill', function () {
    it('should correctly transform action payload', function () {
      expect((0, _actions.cancelSkill)(id)).toEqual({
        payload: {
          id: id,
          path: skillsPath
        },
        type: CANCEL
      });
    });
  });
  describe('fetchSpecialization', function () {
    it('should correctly transform action payload', function () {
      expect((0, _actions.fetchSpecialization)(id)).toEqual({
        payload: {
          id: id,
          path: specializationsPath
        },
        type: FETCH
      });
    });
  });
  describe('cancelSpecialization', function () {
    it('should correctly transform action payload', function () {
      expect((0, _actions.cancelSpecialization)(id)).toEqual({
        payload: {
          id: id,
          path: specializationsPath
        },
        type: CANCEL
      });
    });
  });
  describe('fetchTrait', function () {
    it('should correctly transform action payload', function () {
      expect((0, _actions.fetchTrait)(id)).toEqual({
        payload: {
          id: id,
          path: traitsPath
        },
        type: FETCH
      });
    });
  });
  describe('cancelTrait', function () {
    it('should correctly transform action payload', function () {
      expect((0, _actions.cancelTrait)(id)).toEqual({
        payload: {
          id: id,
          path: traitsPath
        },
        type: CANCEL
      });
    });
  });
});
//# sourceMappingURL=actions.spec.js.map